@@ -6,8 +6,8 @@ from redis.asyncio import Redis as AsyncRedis
 from redis import Redis as SyncRedis
 from sqlalchemy.engine import create_engine as create_sync_engine, Engine
 from sqlalchemy.ext.asyncio import create_async_engine, AsyncEngine
-from typing import Generic, Literal, Optional, TypeVar, Union, overload
-from maleo.types.dict import StringToAnyDict
+from typing import Generic, Literal, TypeVar, overload
+from maleo.types.dict import StrToAnyDict
 from ..enums import Connection
 from .additional import AdditionalConfigT, RedisAdditionalConfig
 from .connection import (
@@ -54,7 +54,7 @@ class ElasticsearchConfig(
     additional: None = None
 
     @property
-    def client_kwargs(self) -> StringToAnyDict:
+    def client_kwargs(self) -> StrToAnyDict:
         client_kwargs = {}
 
         if self.connection.username and self.connection.password:
@@ -75,7 +75,7 @@ class ElasticsearchConfig(
     def create_client(self, connection: Literal[Connection.SYNC]) -> Elasticsearch: ...
     def create_client(
         self, connection: Connection
-    ) -> Union[AsyncElasticsearch, Elasticsearch]:
+    ) -> AsyncElasticsearch | Elasticsearch:
         hosts = [{"host": self.connection.host, "port": self.connection.port}]
         if connection is Connection.ASYNC:
             return AsyncElasticsearch(hosts, **self.client_kwargs)
@@ -93,7 +93,7 @@ class MongoConfig(
     additional: None = None
 
     @property
-    def client_kwargs(self) -> StringToAnyDict:
+    def client_kwargs(self) -> StrToAnyDict:
         return self.pooling.client_kwargs
 
     @overload
@@ -102,9 +102,7 @@ class MongoConfig(
     ) -> AsyncIOMotorClient: ...
     @overload
     def create_client(self, connection: Literal[Connection.SYNC]) -> MongoClient: ...
-    def create_client(
-        self, connection: Connection
-    ) -> Union[AsyncIOMotorClient, MongoClient]:
+    def create_client(self, connection: Connection) -> AsyncIOMotorClient | MongoClient:
         url = self.connection.make_url(connection)
         if connection is Connection.ASYNC:
             return AsyncIOMotorClient(url, **self.client_kwargs)
@@ -122,14 +120,14 @@ class RedisConfig(
     additional: RedisAdditionalConfig = Field(..., description="Additional config")
 
     @property
-    def client_kwargs(self) -> StringToAnyDict:
+    def client_kwargs(self) -> StrToAnyDict:
         return self.pooling.client_kwargs
 
     @overload
     def create_client(self, connection: Literal[Connection.ASYNC]) -> AsyncRedis: ...
     @overload
     def create_client(self, connection: Literal[Connection.SYNC]) -> SyncRedis: ...
-    def create_client(self, connection: Connection) -> Union[AsyncRedis, SyncRedis]:
+    def create_client(self, connection: Connection) -> AsyncRedis | SyncRedis:
         url = self.connection.make_url(connection)
         if connection is Connection.ASYNC:
             return AsyncRedis.from_url(url, **self.client_kwargs)
@@ -155,7 +153,7 @@ class MySQLConfig(
     additional: None = None
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return {
             **self.connection.engine_kwargs,
             **self.pooling.engine_kwargs,
@@ -165,7 +163,7 @@ class MySQLConfig(
     def create_engine(self, connection: Literal[Connection.ASYNC]) -> AsyncEngine: ...
     @overload
     def create_engine(self, connection: Literal[Connection.SYNC]) -> Engine: ...
-    def create_engine(self, connection: Connection) -> Union[AsyncEngine, Engine]:
+    def create_engine(self, connection: Connection) -> AsyncEngine | Engine:
         url = self.connection.make_url(connection)
         if connection is Connection.ASYNC:
             return create_async_engine(url, **self.engine_kwargs)
@@ -183,7 +181,7 @@ class PostgreSQLConfig(
     additional: None = None
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return {
             **self.connection.engine_kwargs,
             **self.pooling.engine_kwargs,
@@ -193,7 +191,7 @@ class PostgreSQLConfig(
     def create_engine(self, connection: Literal[Connection.ASYNC]) -> AsyncEngine: ...
     @overload
     def create_engine(self, connection: Literal[Connection.SYNC]) -> Engine: ...
-    def create_engine(self, connection: Connection) -> Union[AsyncEngine, Engine]:
+    def create_engine(self, connection: Connection) -> AsyncEngine | Engine:
         url = self.connection.make_url(connection)
         if connection is Connection.ASYNC:
             return create_async_engine(url, **self.engine_kwargs)
@@ -211,7 +209,7 @@ class SQLiteConfig(
     additional: None = None
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return {
             **self.connection.engine_kwargs,
             **self.pooling.engine_kwargs,
@@ -221,7 +219,7 @@ class SQLiteConfig(
     def create_engine(self, connection: Literal[Connection.ASYNC]) -> AsyncEngine: ...
     @overload
     def create_engine(self, connection: Literal[Connection.SYNC]) -> Engine: ...
-    def create_engine(self, connection: Connection) -> Union[AsyncEngine, Engine]:
+    def create_engine(self, connection: Connection) -> AsyncEngine | Engine:
         url = self.connection.make_url(connection)
         if connection is Connection.ASYNC:
             return create_async_engine(url, **self.engine_kwargs)
@@ -239,7 +237,7 @@ class SQLServerConfig(
     additional: None = None
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return {
             **self.connection.engine_kwargs,
             **self.pooling.engine_kwargs,
@@ -249,7 +247,7 @@ class SQLServerConfig(
     def create_engine(self, connection: Literal[Connection.ASYNC]) -> AsyncEngine: ...
     @overload
     def create_engine(self, connection: Literal[Connection.SYNC]) -> Engine: ...
-    def create_engine(self, connection: Connection) -> Union[AsyncEngine, Engine]:
+    def create_engine(self, connection: Connection) -> AsyncEngine | Engine:
         url = self.connection.make_url(connection)
         if connection is Connection.ASYNC:
             return create_async_engine(url, **self.engine_kwargs)
@@ -284,23 +282,24 @@ class ElasticsearchConfigs(BaseModel):
     )
 
 
-ElasticsearchConfigsT = TypeVar(
-    "ElasticsearchConfigsT", bound=Optional[ElasticsearchConfigs]
-)
+OptElasticsearchConfigs = ElasticsearchConfigs | None
+ElasticsearchConfigsT = TypeVar("ElasticsearchConfigsT", bound=OptElasticsearchConfigs)
 
 
 class MongoConfigs(BaseModel):
     primary: MongoConfig = Field(..., description="Primary Mongo config")
 
 
-MongoConfigsT = TypeVar("MongoConfigsT", bound=Optional[MongoConfigs])
+OptMongoConfigs = MongoConfigs | None
+MongoConfigsT = TypeVar("MongoConfigsT", bound=OptMongoConfigs)
 
 
 class RedisConfigs(BaseModel):
     primary: RedisConfig = Field(..., description="Primary Redis config")
 
 
-RedisConfigsT = TypeVar("RedisConfigsT", bound=Optional[RedisConfigs])
+OptRedisConfigs = RedisConfigs | None
+RedisConfigsT = TypeVar("RedisConfigsT", bound=OptRedisConfigs)
 
 
 class NoSQLConfigs(
@@ -313,35 +312,40 @@ class NoSQLConfigs(
     redis: RedisConfigsT = Field(..., description="Redis configs")
 
 
-NoSQLConfigsT = TypeVar("NoSQLConfigsT", bound=Optional[NoSQLConfigs])
+OptNoSQLConfigs = NoSQLConfigs | None
+NoSQLConfigsT = TypeVar("NoSQLConfigsT", bound=OptNoSQLConfigs)
 
 
 class MySQLConfigs(BaseModel):
     primary: MySQLConfig = Field(..., description="Primary MySQL config")
 
 
-MySQLConfigsT = TypeVar("MySQLConfigsT", bound=Optional[MySQLConfigs])
+OptMySQLConfigs = MySQLConfigs | None
+MySQLConfigsT = TypeVar("MySQLConfigsT", bound=OptMySQLConfigs)
 
 
 class PostgreSQLConfigs(BaseModel):
     primary: PostgreSQLConfig = Field(..., description="Primary PostgreSQL config")
 
 
-PostgreSQLConfigsT = TypeVar("PostgreSQLConfigsT", bound=Optional[PostgreSQLConfigs])
+OptPostgreSQLConfigs = PostgreSQLConfigs | None
+PostgreSQLConfigsT = TypeVar("PostgreSQLConfigsT", bound=OptPostgreSQLConfigs)
 
 
 class SQLiteConfigs(BaseModel):
     primary: SQLiteConfig = Field(..., description="Primary SQLite config")
 
 
-SQLiteConfigsT = TypeVar("SQLiteConfigsT", bound=Optional[SQLiteConfigs])
+OptSQLiteConfigs = SQLiteConfigs | None
+SQLiteConfigsT = TypeVar("SQLiteConfigsT", bound=OptSQLiteConfigs)
 
 
 class SQLServerConfigs(BaseModel):
     primary: SQLServerConfig = Field(..., description="Primary SQLServer config")
 
 
-SQLServerConfigsT = TypeVar("SQLServerConfigsT", bound=Optional[SQLServerConfigs])
+OptSQLServerConfigs = SQLServerConfigs | None
+SQLServerConfigsT = TypeVar("SQLServerConfigsT", bound=OptSQLServerConfigs)
 
 
 class SQLConfigs(
@@ -359,7 +363,8 @@ class SQLConfigs(
     sqlserver: SQLServerConfigsT = Field(..., description="SQLServer configs")
 
 
-SQLConfigsT = TypeVar("SQLConfigsT", bound=Optional[SQLConfigs])
+OptSQLConfigs = SQLConfigs | None
+SQLConfigsT = TypeVar("SQLConfigsT", bound=OptSQLConfigs)
 
 
 class DatabaseConfigs(
@@ -373,7 +378,8 @@ class DatabaseConfigs(
     sql: SQLConfigsT = Field(..., description="SQL configs")
 
 
-DatabaseConfigsT = TypeVar("DatabaseConfigsT", bound=Optional[DatabaseConfigs])
+OptDatabaseConfigs = DatabaseConfigs | None
+DatabaseConfigsT = TypeVar("DatabaseConfigsT", bound=OptDatabaseConfigs)
 
 
 class DatabaseConfigsMixin(BaseModel, Generic[DatabaseConfigsT]):
