@@ -1,8 +1,8 @@
 from pydantic import BaseModel, ConfigDict, Field, model_validator
 from typing import Annotated, Self, Set, TypeVar
-from maleo.types.dict import OptionalStringToStringDict, StringToAnyDict
-from maleo.types.integer import ListOfIntegers
-from maleo.types.string import OptionalString
+from maleo.types.dict import OptStrToStrDict, StrToAnyDict
+from maleo.types.integer import ListOfInts
+from maleo.types.string import OptStr
 from maleo.utils.formatter import CaseFormatter
 from ..enums import PoolingStrategy
 
@@ -15,9 +15,9 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
     """Elasticsearch-specific pooling configuration."""
 
     block: Annotated[bool, Field(False, description="Block when pool is full")] = False
-    ca_certs: Annotated[
-        OptionalString, Field(None, description="Path to CA certificates")
-    ] = None
+    ca_certs: Annotated[OptStr, Field(None, description="Path to CA certificates")] = (
+        None
+    )
     connections_per_node: Annotated[
         int, Field(10, description="Connections per Elasticsearch node", ge=1, le=50)
     ]
@@ -25,7 +25,7 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
         float, Field(60.0, description="Dead node timeout in seconds", ge=5.0, le=600.0)
     ] = 60.0
     headers: Annotated[
-        OptionalStringToStringDict,
+        OptStrToStrDict,
         Field(None, description="Default headers for requests"),
     ] = None
     http_compress: Annotated[
@@ -39,7 +39,7 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
         Field(25, description="Maximum number of connections in pool", ge=1, le=100),
     ]
     retry_on_status: Annotated[
-        ListOfIntegers,
+        ListOfInts,
         Field(
             [502, 503, 504],
             description="HTTP status codes to retry on",
@@ -71,7 +71,7 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
         }
 
     @property
-    def client_kwargs(self) -> StringToAnyDict:
+    def client_kwargs(self) -> StrToAnyDict:
         return self.model_dump(exclude=self.client_kwargs_exclusions, exclude_none=True)
 
 
@@ -142,7 +142,7 @@ class MongoPoolingConfig(BasePoolingConfig):
     ] = 30_000
 
     @property
-    def client_kwargs(self) -> StringToAnyDict:
+    def client_kwargs(self) -> StrToAnyDict:
         return self.model_dump(by_alias=True, exclude_none=True)
 
 
@@ -177,7 +177,7 @@ class RedisPoolingConfig(BasePoolingConfig):
         return {"health_check_interval", "connection_timeout"}
 
     @property
-    def client_kwargs(self) -> StringToAnyDict:
+    def client_kwargs(self) -> StrToAnyDict:
         return self.model_dump(exclude=self.client_kwargs_exclusions, exclude_none=True)
 
 
@@ -222,7 +222,7 @@ class MySQLPoolingConfig(BasePoolingConfig):
         return {"strategy"}
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
 
 
@@ -279,7 +279,7 @@ class PostgreSQLPoolingConfig(BasePoolingConfig):
         }
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
 
 
@@ -312,7 +312,7 @@ class SQLitePoolingConfig(BasePoolingConfig):
         }
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
 
 
@@ -380,7 +380,7 @@ class SQLServerPoolingConfig(BasePoolingConfig):
         }
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
 
 
