@@ -4,6 +4,7 @@ from pymongo import MongoClient
 from redis.asyncio import Redis as AsyncRedis
 from redis import Redis as SyncRedis
 from typing import Generic, Literal, Tuple, TypeVar, overload
+from maleo.schemas.google import ListOfPublisherHandlers
 from maleo.types.string import ListOfStrs
 from ..config import (
     ElasticsearchConfig,
@@ -29,9 +30,12 @@ class ClientManager(
         SyncClientT,
     ]
 ):
-    def __init__(self, config: NoSQLConfigT) -> None:
+    def __init__(
+        self, config: NoSQLConfigT, publishers: ListOfPublisherHandlers = []
+    ) -> None:
         super().__init__()
         self._config = config
+        self._publishers = publishers
 
         self._async_client = self._config.create_client(Connection.ASYNC)
         self._sync_client = self._config.create_client(Connection.SYNC)
@@ -54,7 +58,7 @@ class ClientManager(
     async def dispose(self):
         if isinstance(self._async_client, AsyncIOMotorClient):
             self._async_client.close()
-        else:
+        elif isinstance(self._async_client, (AsyncElasticsearch, AsyncRedis)):
             await self._async_client.close()
         self._sync_client.close()
 
